{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "cgg-UG",
  date_format_full => "EEEE, d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "ORK",
    "OKB",
    "OKS",
    "OKN",
    "OKT",
    "OMK",
    "SAN",
  ],
  day_format_narrow => [
    "K",
    "R",
    "S",
    "N",
    "T",
    "M",
    "S",
  ],
  day_format_wide => [
    "Orwokubanza",
    "Orwakabiri",
    "Orwakashatu",
    "Orwakana",
    "Orwakataano",
    "Orwamukaaga",
    "Sande",
  ],
  day_stand_alone_abbreviated => [
    "ORK",
    "OKB",
    "OKS",
    "OKN",
    "OKT",
    "OMK",
    "SAN",
  ],
  day_stand_alone_narrow => [
    "K",
    "R",
    "S",
    "N",
    "T",
    "M",
    "S",
  ],
  day_stand_alone_wide => [
    "Orwokubanza",
    "Orwakabiri",
    "Orwakashatu",
    "Orwakana",
    "Orwakataano",
    "Orwamukaaga",
    "Sande",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Kurisito Atakaijire",
    "Kurisito Yaijire",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Chiga",
  month_format_abbreviated => [
    "KBZ",
    "KBR",
    "KST",
    "KKN",
    "KTN",
    "KMK",
    "KMS",
    "KMN",
    "KMW",
    "KKM",
    "KNK",
    "KNB",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Okwokubanza",
    "Okwakabiri",
    "Okwakashatu",
    "Okwakana",
    "Okwakataana",
    "Okwamukaaga",
    "Okwamushanju",
    "Okwamunaana",
    "Okwamwenda",
    "Okwaikumi",
    "Okwaikumi na kumwe",
    "Okwaikumi na ibiri",
  ],
  month_stand_alone_abbreviated => [
    "KBZ",
    "KBR",
    "KST",
    "KKN",
    "KTN",
    "KMK",
    "KMS",
    "KMN",
    "KMW",
    "KKM",
    "KNK",
    "KNB",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Okwokubanza",
    "Okwakabiri",
    "Okwakashatu",
    "Okwakana",
    "Okwakataana",
    "Okwamukaaga",
    "Okwamushanju",
    "Okwamunaana",
    "Okwamwenda",
    "Okwaikumi",
    "Okwaikumi na kumwe",
    "Okwaikumi na ibiri",
  ],
  name => "Chiga Uganda",
  native_language => "Rukiga",
  native_name => "Rukiga Uganda",
  native_script => undef,
  native_territory => "Uganda",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "KWOTA 1",
    "KWOTA 2",
    "KWOTA 3",
    "KWOTA 4",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "KWOTA 1",
    "KWOTA 2",
    "KWOTA 3",
    "KWOTA 4",
  ],
  script => undef,
  territory => "Uganda",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}
